@@ -41,6 +41,7 @@
 #include "libkwave/PluginContext.h"
 #include "libkwave/SampleReader.h"
 #include "libkwave/SignalManager.h"
+#include "libkwave/Utils.h"
 #include "libkwave/Writer.h"
 #include "libkwave/undo/UndoTransactionGuard.h"
 #include "libkwave/undo/UndoAction.h"
@@ -85,7 +86,8 @@ Kwave::PluginManager::PluginDeleter::~PluginDeleter()
 
 // static initializers
 
-QMap<QString, QString> Kwave::PluginManager::m_plugin_files;
+QMap<QString, Kwave::PluginManager::PluginInfo> \
+    Kwave::PluginManager::m_found_plugins;
 
 Kwave::PluginManager::PluginList Kwave::PluginManager::m_unique_plugins;
 
@@ -94,8 +96,11 @@ static QList<PlaybackDeviceFactory *> m_playback_factories;
 //***************************************************************************
 Kwave::PluginManager::PluginManager(QWidget *parent,
                                     SignalManager &signal_manager)
-    :m_loaded_plugins(), m_running_plugins(),
-     m_parent_widget(parent), m_signal_manager(signal_manager)
+    :m_loaded_plugins(),
+     m_running_plugins(),
+     m_parent_widget(parent),
+     m_signal_manager(signal_manager),
+     m_view_manager(0)
 {
     // connect all unique plugins
     foreach (KwavePluginPointer p, m_unique_plugins) {
@@ -154,7 +159,7 @@ void Kwave::PluginManager::loadAllPlugins()
     // Try to load all plugins. This has to be called only once per
     // instance of the main window!
     // NOTE: this also implicitely makes it resident if it is persistent or unique
-    foreach (QString name, m_plugin_files.keys()) {
+    foreach (QString name, m_found_plugins.keys()) {
 	KwavePluginPointer plugin = loadPlugin(name);
 	if (plugin) {
 // 	    QString state = "";
@@ -165,14 +170,14 @@ void Kwave::PluginManager::loadAllPlugins()
 // 		   plugin->name().toLocal8Bit().data(),
 // 		   state.toLocal8Bit().data());
 
-	    // reduce us count again, unique and persistent plugins
+	    // reduce use count again, unique and persistent plugins
 	    // stay loaded with use count 1
 	    plugin->release();
 	} else {
 	    // loading failed => remove it from the list
 	    qWarning("PluginManager::loadAllPlugins(): removing '%s' "\
 	            "from list", name.toLocal8Bit().data());
-	    m_plugin_files.remove(name);
+	    m_found_plugins.remove(name);
 	}
     }
 }
@@ -210,23 +215,23 @@ Kwave::Plugin *Kwave::PluginManager::loadPlugin(const QString &name)
     }
 
     // show a warning and abort if the plugin is unknown
-    if (!(m_plugin_files.contains(name))) {
+    if (!(m_found_plugins.contains(name))) {
 	QString message =
-	    i18n("oops, plugin '%1' is unknown or invalid!", name);
+	    i18n("The plugin '%1' is unknown or invalid.", name);
 	Kwave::MessageBox::error(m_parent_widget, message,
-	    i18n("error on loading plugin"));
+	    i18n("Error On Loading Plugin"));
 	return 0;
     }
-    QString &filename = m_plugin_files[name];
+    QString &filename = m_found_plugins[name].m_filename;
 
     // try to get the file handle of the plugin's binary
     void *handle = dlopen(filename.toLocal8Bit(), RTLD_NOW);
     if (!handle) {
-	QString message = i18n("unable to load the file \n'%1'\n"\
-	                       " that contains the plugin '%2' !",
+	QString message = i18n("Unable to load the file\n'%1'\n"\
+	                       "that contains the plugin '%2'.",
 	                       filename, name);
 	Kwave::MessageBox::error(m_parent_widget, message,
-	    i18n("error on loading plugin"));
+	    i18n("Error On Loading Plugin"));
 	return 0;
     }
 
@@ -245,7 +250,7 @@ Kwave::Plugin *Kwave::PluginManager::loadPlugin(const QString &name)
 	static_cast<const char **>(dlsym(handle, sym_author));
     Q_ASSERT(pauthor);
     if (pauthor) author=*pauthor;
-    if (!author) author = i18n("(unknown)").toLocal8Bit();
+    if (!author) author = i18n("(Unknown)").toLocal8Bit();
 
     // get the plugin's version string
     const char *version = "";
@@ -253,7 +258,7 @@ Kwave::Plugin *Kwave::PluginManager::loadPlugin(const QString &name)
 	static_cast<const char **>(dlsym(handle, sym_version));
     Q_ASSERT(pver);
     if (pver) version=*pver;
-    if (!version) version = i18n("(unknown)").toLocal8Bit();
+    if (!version) version = i18n("(Unknown)").toLocal8Bit();
 
     plugin_loader =
         reinterpret_cast<Kwave::Plugin *(*)(const PluginContext *)>(
@@ -416,7 +421,7 @@ void Kwave::PluginManager::sync()
     qApp->flush();
 
     while (onePluginRunning()) {
-	pthread_yield();
+	Kwave::yield();
 	qApp->processEvents();
 	qApp->flush();
     }
@@ -448,12 +453,6 @@ int Kwave::PluginManager::setupPlugin(const QString &name)
     return 0;
 }
 
-//***************************************************************************
-FileInfo &Kwave::PluginManager::fileInfo()
-{
-    return m_signal_manager.fileInfo();
-}
-
 //***************************************************************************
 QStringList Kwave::PluginManager::loadPluginDefaults(const QString &name,
                                                      const QString &version)
@@ -504,7 +503,7 @@ void Kwave::PluginManager::savePluginDefaults(const QString &name,
 }
 
 //***************************************************************************
-unsigned int Kwave::PluginManager::signalLength()
+sample_index_t Kwave::PluginManager::signalLength()
 {
     return m_signal_manager.length();
 }
@@ -522,31 +521,24 @@ const QList<unsigned int> Kwave::PluginManager::selectedTracks()
 }
 
 //***************************************************************************
-unsigned int Kwave::PluginManager::selectionStart()
+sample_index_t Kwave::PluginManager::selectionStart()
 {
     return m_signal_manager.selection().first();
 }
 
 //***************************************************************************
-unsigned int Kwave::PluginManager::selectionEnd()
+sample_index_t Kwave::PluginManager::selectionEnd()
 {
     return m_signal_manager.selection().last();
 }
 
 //***************************************************************************
-void Kwave::PluginManager::selectRange(unsigned int offset,
-                                       unsigned int length)
+void Kwave::PluginManager::selectRange(sample_index_t offset,
+                                       sample_index_t length)
 {
     m_signal_manager.selectRange(offset, length);
 }
 
-//***************************************************************************
-Kwave::Writer *Kwave::PluginManager::openWriter(unsigned int track,
-	InsertMode mode, unsigned int left, unsigned int right)
-{
-    return m_signal_manager.openWriter(track, mode, left, right, true);
-}
-
 //***************************************************************************
 Kwave::SampleSink *Kwave::PluginManager::openMultiTrackPlayback(
     unsigned int tracks, const QString *name)
@@ -582,6 +574,20 @@ PlaybackController &Kwave::PluginManager::playbackController()
     return m_signal_manager.playbackController();
 }
 
+//***************************************************************************
+void Kwave::PluginManager::insertView(Kwave::SignalView *view, QWidget *controls)
+{
+    if (m_view_manager)
+	m_view_manager->insertView(view, controls);
+}
+
+//***************************************************************************
+void Kwave::PluginManager::registerViewManager(Kwave::ViewManager *view_manager)
+{
+    Q_ASSERT(!view_manager || !m_view_manager);
+    m_view_manager = view_manager;
+}
+
 //***************************************************************************
 void Kwave::PluginManager::enqueueCommand(const QString &command)
 {
@@ -706,7 +712,7 @@ void Kwave::PluginManager::setSignalName(const QString &name)
 //***************************************************************************
 void Kwave::PluginManager::findPlugins()
 {
-    if (!m_plugin_files.isEmpty()) {
+    if (!m_found_plugins.isEmpty()) {
 	// this is not the first call -> bail out
 	return;
     }
@@ -726,17 +732,26 @@ void Kwave::PluginManager::findPlugins()
 		static_cast<const char **>(dlsym(handle, "name"));
 	    const char **version =
 		static_cast<const char **>(dlsym(handle, "version"));
+	    const char **description =
+		static_cast<const char **>(dlsym(handle, "description"));
 	    const char **author  =
 		static_cast<const char **>(dlsym(handle, "author"));
 
 	    // skip it if something is missing or null
-	    if (!name || !version || !author) continue;
-	    if (!*name || !*version || !*author) continue;
+	    if (!name || !version || !author || !description) continue;
+	    if (!*name || !*version || !*author || !*description) continue;
 
-	    emit sigProgress(i18n("loading plugin %1...", *name));
+	    emit sigProgress(i18n("Loading plugin %1...", *name));
 	    QApplication::processEvents();
 
-	    m_plugin_files.insert(*name, file);
+	    PluginInfo info;
+	    info.m_filename    = file;
+	    info.m_author      = QString::fromUtf8(*author);
+	    info.m_description = i18n(*description);
+	    info.m_version     = QString::fromUtf8(*version);
+
+	    m_found_plugins.insert(*name, info);
+
 	    qDebug("%16s %5s written by %s",
 		*name, *version, *author);
 
@@ -747,7 +762,14 @@ void Kwave::PluginManager::findPlugins()
 	}
     }
 
-    qDebug("--- \n found %d plugins\n", m_plugin_files.count());
+    qDebug("--- \n found %d plugins\n", m_found_plugins.count());
+}
+
+//***************************************************************************
+const QList<Kwave::PluginManager::PluginInfo>
+    Kwave::PluginManager::pluginInfoList() const
+{
+    return m_found_plugins.values();
 }
 
 //***************************************************************************
