@@ -34,6 +34,8 @@ extern "C" {
 #include "libkwave/MultiWriter.h"
 #include "libkwave/Label.h"
 #include "libkwave/MessageBox.h"
+#include "libkwave/MetaData.h"
+#include "libkwave/MetaDataList.h"
 #include "libkwave/Sample.h"
 #include "libkwave/Signal.h"
 #include "libkwave/VirtualAudioFile.h"
@@ -111,7 +113,10 @@ Decoder *WavDecoder::instance()
 //***************************************************************************
 bool WavDecoder::open(QWidget *widget, QIODevice &src)
 {
-    info().clear();
+    FileInfo info;
+    LabelList labels;
+    metaData().clear();
+
     Q_ASSERT(!m_source);
     bool need_repair = false;
     if (m_source) qWarning("WavDecoder::open(), already open !");
@@ -133,13 +138,13 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 
     // prepare a progress dialog
     QProgressDialog progress(widget);
-    progress.setWindowTitle(i18n("Auto-Repair"));
+    progress.setWindowTitle(i18n("Auto Repair"));
     progress.setModal(true);
     progress.setMinimumDuration(0);
     progress.setMaximum(100);
     progress.setAutoClose(true);
     progress.setValue(0);
-    progress.setLabelText(i18n("reading..."));
+    progress.setLabelText(i18n("Reading..."));
     connect(&parser,   SIGNAL(progress(int)),
             &progress, SLOT(setValue(int)));
     connect(&parser,   SIGNAL(action(const QString &)),
@@ -164,9 +169,9 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
     if (!riff_chunk || !fmt_chunk || !data_chunk || !parser.isSane()) {
 	if (Kwave::MessageBox::warningContinueCancel(widget,
 	    i18n("The file has been structurally damaged or "
-	         "is no .wav file.\n"
+	         "it is no WAV file.\n"
 	         "Should Kwave try to repair it?"),
-	    i18n("Kwave auto repair"),
+	    i18n("Kwave Auto Repair"),
 	    i18n("&Repair")) != KMessageBox::Continue)
 	{
 	    // user didn't let us try :-(
@@ -217,19 +222,19 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
     if (fmt_chunk) fmt_offset = fmt_chunk->dataStart();
 //     qDebug("fmt chunk starts at 0x%08X", fmt_offset);
 
-    u_int32_t data_offset = 0;
+//     u_int32_t data_offset = 0;
     u_int32_t data_size = 0;
     if (data_chunk) {
-	data_offset = data_chunk->dataStart();
+// 	data_offset = data_chunk->dataStart();
 	data_size   = data_chunk->physLength();
 // 	qDebug("data chunk at 0x%08X (%u byte)", data_offset, data_size);
     }
 
     if (!data_size) {
 	Kwave::MessageBox::sorry(widget,
-	    i18n("The opened file is no .WAV file or damaged:\n"
+	    i18n("The opened file is no WAV file or it is damaged:\n"
 	    "There is not enough valid sound data.\n\n"
-	    "It makes no sense to continue now..."));
+	    "It makes no sense to continue now."));
 	return false;
     }
 
@@ -239,14 +244,14 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
         (parser.chunkCount("data") != 1))
     {
 	if (Kwave::MessageBox::warningContinueCancel(widget,
-	    i18n("The WAV file seems to be damaged: \n"
-	         "some chunks are duplicate or missing! \n\n"
-	         "Kwave will only use the first ones and ignores\n"
-	         "the rest. This might lead to a loss of data. If\n"
+	    i18n("The WAV file seems to be damaged:\n"
+	         "Some chunks are duplicate or missing.\n\n"
+	         "Kwave will only use the first ones and ignore\n"
+	         "the rest. This might lead to loss of data.\n"
 	         "If you want to get your file repaired completely,\n"
-	         "please write an e-mail to the Kwave mailing list\n"
-	         "and we will help you..."),
-	    i18n("Kwave auto-repair")
+	         "please write an email to the Kwave mailing list\n"
+	         "and we will help you."),
+	    i18n("Kwave Auto Repair")
 	    ) != KMessageBox::Continue)
 	{
 	    // user decided to abort and repair on his own
@@ -326,34 +331,37 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 
 	switch (m_src_adapter->lastError()) {
 	    case AF_BAD_NOT_IMPLEMENTED:
-	        reason = i18n("format or function is not implemented") +
+	        reason = i18n("Format or function is not implemented") +
 		         "\n("+format_name+")";
 	        break;
 	    case AF_BAD_MALLOC:
-	        reason = i18n("out of memory");
+	        reason = i18n("Out of memory");
 	        break;
 	    case AF_BAD_HEADER:
 	        reason = i18n("file header is damaged");
 	        break;
 	    case AF_BAD_CODEC_TYPE:
-	        reason = i18n("invalid codec type") +
+	        reason = i18n("Invalid codec type") +
 		         "\n("+format_name+")";
 	        break;
 	    case AF_BAD_OPEN:
-	        reason = i18n("opening the file failed");
+	        reason = i18n("Opening the file failed");
 	        break;
 	    case AF_BAD_READ:
-	        reason = i18n("read access failed");
+	        reason = i18n("Read access failed");
 	        break;
 	    case AF_BAD_SAMPFMT:
-	        reason = i18n("invalid sample format");
+	        reason = i18n("Invalid sample format");
 	        break;
 	    default:
-		reason = reason.number(m_src_adapter->lastError());
+		reason = i18n("internal libaudiofile error #%1: '%2'",
+		    m_src_adapter->lastError(),
+		    m_src_adapter->lastErrorText()
+		);
 	}
 
-	QString text= i18n("An error occurred while opening the "\
-	    "file:\n'%1'", reason);
+	QString text= i18n("An error occurred while opening the file:\n'%1'", 
+	                    reason);
 	Kwave::MessageBox::error(widget, text);
 
 	return false;
@@ -369,12 +377,12 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
     int compression = afGetCompression(fh, AF_DEFAULT_TRACK);
     if (static_cast<signed int>(bits) < 0) bits = 0;
 
-    info().setRate(rate);
-    info().setBits(bits);
-    info().setTracks(tracks);
-    info().setLength(length);
-    info().set(INF_SAMPLE_FORMAT, sample_format);
-    info().set(INF_COMPRESSION, compression);
+    info.setRate(rate);
+    info.setBits(bits);
+    info.setTracks(tracks);
+    info.setLength(length);
+    info.set(INF_SAMPLE_FORMAT, sample_format);
+    info.set(INF_COMPRESSION, compression);
 
     // read in all info from the LIST (INFO) chunk
     RIFFChunk *info_chunk = parser.findChunk("/RIFF:WAVE/LIST:INFO");
@@ -395,7 +403,7 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 	    buffer[length] = 0;
 	    QString value;
 	    value = QString::fromUtf8(buffer);
-	    info().set(prop, value);
+	    info.set(prop, value);
 	}
     }
 
@@ -511,10 +519,12 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 
 	    // put a new label into the list
 	    QString str = QString::fromUtf8(name);
-	    info().labels().append(Label(position, str));
+	    labels.append(Label(position, str));
 	}
     }
-    info().labels().sort();
+    labels.sort();
+    metaData().replace(info);
+    metaData().replace(labels.toMetaDataList());
 
     // set up libaudiofile to produce Kwave's internal sample format
 #if Q_BYTE_ORDER == Q_BIG_ENDIAN
@@ -541,10 +551,11 @@ bool WavDecoder::decode(QWidget */*widget*/, Kwave::MultiWriter &dst)
     if (!fh) return false;
 
 //     info().dump();
+    const unsigned int tracks = dst.tracks();
 
     // allocate an array of Writers, for speeding up
     QVector<Kwave::Writer *>writers;
-    for (unsigned int t = 0; t < dst.tracks(); t++)
+    for (unsigned int t = 0; t < tracks; t++)
 	writers.append(dst[t]);
     Q_ASSERT(writers.count() == static_cast<int>(dst.tracks()));
     if (writers.count() != static_cast<int>(dst.tracks())) return false;
@@ -561,8 +572,8 @@ bool WavDecoder::decode(QWidget */*widget*/, Kwave::MultiWriter &dst)
     if (!buffer) return false;
 
     // read in from the audiofile source
-    const unsigned int tracks = info().tracks();
-    unsigned int rest = info().length();
+    Q_ASSERT(tracks == FileInfo(metaData()).tracks());
+    sample_index_t rest = FileInfo(metaData()).length();
     while (rest) {
 	unsigned int frames = buffer_frames;
 	if (frames > rest) frames = rest;
@@ -582,11 +593,12 @@ bool WavDecoder::decode(QWidget */*widget*/, Kwave::MultiWriter &dst)
 
 		// adjust precision
 		if (SAMPLE_STORAGE_BITS != SAMPLE_BITS) {
-		    s /= (1 << (SAMPLE_STORAGE_BITS-SAMPLE_BITS));
+		    s /= (1 << (SAMPLE_STORAGE_BITS - SAMPLE_BITS));
 		}
 
 		// the following cast is only necessary if
 		// sample_t is not equal to a u_int32_t
+		Q_ASSERT(writer_fast[track]);
 		*(writer_fast[track]) << static_cast<sample_t>(s);
 	    }
 	}
