@@ -183,9 +183,9 @@ void WavEncoder::writeInfoChunk(QIODevice &dst, FileInfo &info)
 }
 
 /***************************************************************************/
-void WavEncoder::writeLabels(QIODevice &dst, FileInfo &info)
+void WavEncoder::writeLabels(QIODevice &dst, const LabelList &labels)
 {
-    const unsigned int labels_count = info.labels().count();
+    const unsigned int labels_count = labels.count();
     u_int32_t size, additional_size = 0, index, data;
 
     // shortcut: nothing to do if no labels present
@@ -199,7 +199,7 @@ void WavEncoder::writeLabels(QIODevice &dst, FileInfo &info)
 
     // now the size of the labels
     unsigned int size_of_labels = 0;
-    foreach (const Label &label, info.labels()) {
+    foreach (const Label &label, labels) {
 	if (label.isNull()) continue;
 	unsigned int name_len = label.name().toUtf8().size();
 	if (!name_len) continue; // skip zero-length names
@@ -237,7 +237,7 @@ void WavEncoder::writeLabels(QIODevice &dst, FileInfo &info)
     dst.write(reinterpret_cast<char *>(&size), 4);
 
     index = 0;
-    foreach (const Label &label, info.labels()) {
+    foreach (const Label &label, labels) {
 	if (label.isNull()) continue;
 	/*
 	 * typedef struct {
@@ -268,7 +268,7 @@ void WavEncoder::writeLabels(QIODevice &dst, FileInfo &info)
 	dst.write(reinterpret_cast<char *>(&size), 4);
 	dst.write("adtl", 4);
 	index = 0;
-	foreach (const Label &label, info.labels()) {
+	foreach (const Label &label, labels) {
 	    if (label.isNull()) continue;
 	    QByteArray name = label.name().toUtf8();
 
@@ -304,8 +304,10 @@ void WavEncoder::writeLabels(QIODevice &dst, FileInfo &info)
 
 /***************************************************************************/
 bool WavEncoder::encode(QWidget *widget, MultiTrackReader &src,
-                        QIODevice &dst, FileInfo &info)
+                        QIODevice &dst, const Kwave::MetaDataList &meta_data)
 {
+    FileInfo info(meta_data);
+
     /* first get and check some header information */
     const unsigned int tracks = info.tracks();
     const unsigned int length = info.length();
@@ -323,8 +325,6 @@ bool WavEncoder::encode(QWidget *widget, MultiTrackReader &src,
     if (!bits) bits = 16;
 
     // check for a valid source
-    Q_ASSERT(tracks);
-    Q_ASSERT(length);
     if ((!tracks) || (!length)) return false;
     Q_ASSERT(src.tracks() == tracks);
     if (src.tracks() != tracks) return false;
@@ -336,8 +336,8 @@ bool WavEncoder::encode(QWidget *widget, MultiTrackReader &src,
     {
 	qWarning("compression mode %d not supported!", compression);
 	int what_now = Kwave::MessageBox::warningYesNoCancel(widget,
-	    i18n("Sorry, the currently selected compression type can "
-	         "not be used for saving. Do you want to use "
+	    i18n("Sorry, the currently selected compression type cannot "
+	         "be used for saving. Do you want to use "
 	         "G711 ULAW compression instead?"), QString(),
 	    i18n("&Yes, use G711"),
 	    i18n("&No, store uncompressed")
@@ -408,27 +408,27 @@ bool WavEncoder::encode(QWidget *widget, MultiTrackReader &src,
 
 	switch (outfile.lastError()) {
 	    case AF_BAD_NOT_IMPLEMENTED:
-	        reason = i18n("format or function is not implemented") /*+
+	        reason = i18n("Format or function is not implemented") /*+
 		         "\n("+format_name+")"*/;
 	        break;
 	    case AF_BAD_MALLOC:
-	        reason = i18n("out of memory");
+	        reason = i18n("Out of memory");
 	        break;
 	    case AF_BAD_HEADER:
-	        reason = i18n("file header is damaged");
+	        reason = i18n("File header is damaged");
 	        break;
 	    case AF_BAD_CODEC_TYPE:
-	        reason = i18n("invalid codec type")/* +
+	        reason = i18n("Invalid codec type")/* +
 		         "\n("+format_name+")"*/;
 	        break;
 	    case AF_BAD_OPEN:
-	        reason = i18n("opening the file failed");
+	        reason = i18n("Opening the file failed");
 	        break;
 	    case AF_BAD_READ:
-	        reason = i18n("read access failed");
+	        reason = i18n("Read access failed");
 	        break;
 	    case AF_BAD_SAMPFMT:
-	        reason = i18n("invalid sample format");
+	        reason = i18n("Invalid sample format");
 	        break;
 	    default:
 		reason = reason.number(outfile.lastError());
@@ -514,7 +514,7 @@ bool WavEncoder::encode(QWidget *widget, MultiTrackReader &src,
     writeInfoChunk(dst, info);
 
     // write the labels list
-    writeLabels(dst, info);
+    writeLabels(dst, LabelList(meta_data));
 
     return true;
 }
