@@ -56,11 +56,13 @@
 #include "PlayBack-OSS.h"
 #include "PlayBack-ALSA.h"
 #include "PlayBack-Phonon.h"
+#include "PlayBack-PulseAudio.h"
 
 #include "PlayBackDialog.h"
 #include "PlayBackPlugin.h"
 
-KWAVE_PLUGIN(PlayBackPlugin,"playback","2.2","Thomas Eschenbacher");
+KWAVE_PLUGIN(PlayBackPlugin, "playback", "2.2",
+             I18N_NOOP("Playback"), "Thomas Eschenbacher");
 
 /** Sets the number of screen refreshes per second when in playback mode */
 #define SCREEN_REFRESHES_PER_SECOND 16
@@ -81,15 +83,14 @@ PlayBackPlugin::PlayBackPlugin(const PluginContext &context)
 
     connect(this, SIGNAL(sigPlaybackDone()),
             &m_playback_controller, SLOT(playbackDone()));
-    connect(this, SIGNAL(sigPlaybackPos(unsigned int)),
-            &m_playback_controller, SLOT(updatePlaybackPos(unsigned int)));
+    connect(this, SIGNAL(sigPlaybackPos(sample_index_t)),
+            &m_playback_controller, SLOT(updatePlaybackPos(sample_index_t)));
     connect(this, SIGNAL(sigPlaybackDone()),
             this, SLOT(closeDevice()),
             Qt::QueuedConnection);
 
     // register as a factory for playback devices
     manager().registerPlaybackDeviceFactory(this);
-    i18n("playback");
 }
 
 //***************************************************************************
@@ -267,6 +268,12 @@ PlayBackDevice *PlayBackPlugin::createDevice(playback_method_t &method)
 		return new PlayBackPhonon();
 #endif /* HAVE_PHONON_SUPPORT */
 
+#ifdef HAVE_PULSEAUDIO_SUPPORT
+	    case PLAYBACK_PULSEAUDIO:
+		return new PlayBackPulseAudio(
+		    FileInfo(signalManager().metaData()));
+#endif /* HAVE_PULSEAUDIO_SUPPORT */
+
 	    default:
 		qDebug("unsupported playback method (%d)",
 		    static_cast<int>(method));
@@ -380,6 +387,9 @@ void PlayBackPlugin::setDevice(const QString &device)
     QString dev = device;
     if (m_device) {
 	QStringList supported = m_device->supportedDevices();
+	supported.removeAll("#EDIT#");
+	supported.removeAll("#SELECT#");
+	supported.removeAll("#TREE#");
 	if (!supported.isEmpty() && !supported.contains(device)) {
 	    // use the first entry as default
 	    dev = supported.first();
@@ -417,7 +427,7 @@ PlayBackDevice *PlayBackPlugin::openDevice(const QString &name,
 	// use default parameters if none given
 	params          = m_playback_params;
 	if (!signalManager().isClosed() && !signalManager().isEmpty()) {
-	    params.rate     = fileInfo().rate();
+	    params.rate     = FileInfo(signalManager().metaData()).rate();
 	    params.channels = selectedTracks().count();
 	}
     } else {
@@ -458,7 +468,7 @@ PlayBackDevice *PlayBackPlugin::openDevice(const QString &name,
 
 	// show an error message box
 	Kwave::MessageBox::error(parentWidget(), result,
-	    i18n("unable to open '%1'",
+	    i18n("Unable to open '%1'",
 	    params.device.section('|',0,0)));
     }
 
@@ -503,8 +513,8 @@ void PlayBackPlugin::startDevicePlayBack()
 	return;
     }
 
-    unsigned int first;
-    unsigned int last;
+    sample_index_t first;
+    sample_index_t last;
     selection(0, &first, &last, false);
 
     if (m_playback_controller.paused()) {
@@ -527,7 +537,6 @@ void PlayBackPlugin::startDevicePlayBack()
 		// nothing selected -> select all and move to position
 		m_playback_controller.setStartPos(first);
 		m_playback_controller.setEndPos(signalLength()-1);
-		m_playback_controller.updatePlaybackPos(first);
 	    }
 	}
     } else {
@@ -548,7 +557,6 @@ void PlayBackPlugin::startDevicePlayBack()
     m_old_last = last;
 
     QStringList empty_list;
-    use();
     execute(empty_list);
 }
 
@@ -575,8 +583,8 @@ void PlayBackPlugin::run(QStringList)
     // get the list of selected channels
     QList<unsigned int> audible_tracks = selectedTracks();
     unsigned int audible_count = audible_tracks.count();
-    if (!audible_count) {
-	// not even one selected track
+    if (!audible_count || !m_device) {
+	// not even one selected track or no (open) device
 	qDebug("PlayBackPlugin::run(): no audible track(s) !");
 	emit sigPlaybackDone();
 	return;
@@ -701,7 +709,7 @@ void PlayBackPlugin::testPlayBack()
     // check if we really have selected a playback device
     if (!playback_params.device.length()) {
 	Kwave::MessageBox::sorry(m_dialog, i18n(
-	    "please select a playback device first"));
+	    "Please select a playback device first"));
 	return;
     }
 
@@ -788,8 +796,8 @@ void PlayBackPlugin::testPlayBack()
 	    progress->setValue(1);
 	    progress->setLabelText(
 		"<html><p><br>" +
-		i18n("you should now hear a %1Hz test tone...<br><br>"\
-		     "(if you hear clicks or dropouts, please increase<br>"\
+		i18n("You should now hear a %1 Hz test tone.<br><br>"\
+		     "(If you hear clicks or dropouts, please increase<br>"\
 		     "the buffer size and try again)", static_cast<int>(freq)) +
 		"</p></html>"
 	    );
